@@ -21,8 +21,7 @@ from botocore.model import ServiceModel
 from botocore import serialize
 from botocore.compat import six
 from botocore.exceptions import ParamValidationError
-from botocore.serialize import Serializer
-from botocore.validate import ParamValidationDecorator
+from botocore.serialize import SERIALIZERS
 
 
 class BaseModelWithBlob(unittest.TestCase):
@@ -76,6 +75,8 @@ class TestBinaryTypes(BaseModelWithBlob):
     def test_blob_accepts_bytes_type(self):
         body = b'bytes body'
         request = self.serialize_to_request(input_params={'Blob': body})
+        self.assert_serialized_blob_equals(
+            request, blob_bytes=body)
 
     def test_blob_accepts_str_type(self):
         body = u'ascii text'
@@ -91,6 +92,7 @@ class TestBinaryTypes(BaseModelWithBlob):
 
 
 class TestBinaryTypesJSON(BaseModelWithBlob):
+
     def setUp(self):
         super(TestBinaryTypesJSON, self).setUp()
         self.model['metadata'] = {
@@ -110,6 +112,7 @@ class TestBinaryTypesJSON(BaseModelWithBlob):
 
 
 class TestBinaryTypesWithRestXML(BaseModelWithBlob):
+
     def setUp(self):
         super(TestBinaryTypesWithRestXML, self).setUp()
         self.model['metadata'] = {
@@ -213,6 +216,7 @@ class TestTimestampHeadersWithRestXML(unittest.TestCase):
 
 
 class TestTimestamps(unittest.TestCase):
+
     def setUp(self):
         self.model = {
             'metadata': {'protocol': 'query', 'apiVersion': '2014-01-01'},
@@ -259,14 +263,16 @@ class TestTimestamps(unittest.TestCase):
         self.assertEqual(request['body']['Timestamp'], '2014-01-01T12:12:12Z')
 
     def test_accepts_iso_8601_format(self):
-        request = self.serialize_to_request({'Timestamp': '2014-01-01T12:12:12Z'})
+        request = self.serialize_to_request(
+            {'Timestamp': '2014-01-01T12:12:12Z'})
         self.assertEqual(request['body']['Timestamp'], '2014-01-01T12:12:12Z')
 
     def test_accepts_timestamp_without_tz_info(self):
         # If a timezone/utc is not specified, assume they meant
         # UTC.  This is also the previous behavior from older versions
         # of botocore so we want to make sure we preserve this behavior.
-        request = self.serialize_to_request({'Timestamp': '2014-01-01T12:12:12'})
+        request = self.serialize_to_request(
+            {'Timestamp': '2014-01-01T12:12:12'})
         self.assertEqual(request['body']['Timestamp'], '2014-01-01T12:12:12Z')
 
     def test_microsecond_timestamp_without_tz_info(self):
@@ -277,6 +283,7 @@ class TestTimestamps(unittest.TestCase):
 
 
 class TestJSONTimestampSerialization(unittest.TestCase):
+
     def setUp(self):
         self.model = {
             'metadata': {'protocol': 'json', 'apiVersion': '2014-01-01',
@@ -333,6 +340,7 @@ class TestJSONTimestampSerialization(unittest.TestCase):
 
 
 class TestInstanceCreation(unittest.TestCase):
+
     def setUp(self):
         self.model = {
             'metadata': {'protocol': 'query', 'apiVersion': '2014-01-01'},
@@ -385,12 +393,14 @@ class TestInstanceCreation(unittest.TestCase):
         try:
             self.assert_serialize_valid_parameter(request_serializer)
         except ParamValidationError as e:
-            self.fail("Shouldn't fail serializing valid parameter without validation")
+            self.fail(
+                "Shouldn't fail serializing valid parameter without validation".format(e))
 
         try:
             self.assert_serialize_invalid_parameter(request_serializer)
         except ParamValidationError as e:
-            self.fail("Shouldn't fail serializing invalid parameter without validation")
+            self.fail(
+                "Shouldn't fail serializing invalid parameter without validation".format(e))
 
     def test_instantiate_with_validation(self):
         request_serializer = serialize.create_serializer(
@@ -398,13 +408,15 @@ class TestInstanceCreation(unittest.TestCase):
         try:
             self.assert_serialize_valid_parameter(request_serializer)
         except ParamValidationError as e:
-            self.fail("Shouldn't fail serializing valid parameter with validation")
+            self.fail(
+                "Shouldn't fail serializing valid parameter with validation".format(e))
 
         with self.assertRaises(ParamValidationError):
             self.assert_serialize_invalid_parameter(request_serializer)
 
 
 class TestHeaderSerialization(BaseModelWithBlob):
+
     def setUp(self):
         self.model = {
             'metadata': {'protocol': 'rest-xml', 'apiVersion': '2014-01-01'},
@@ -443,6 +455,7 @@ class TestHeaderSerialization(BaseModelWithBlob):
 
 
 class TestRestXMLUnicodeSerialization(unittest.TestCase):
+
     def setUp(self):
         self.model = {
             'metadata': {'protocol': 'rest-xml', 'apiVersion': '2014-01-01'},
